#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 yesod
version:              1.6.1.0
visibility:           public
id:                   yesod-1.6.1.0-DVYTfX6pgH0746VC0hSDHF
key:                  yesod-1.6.1.0-DVYTfX6pgH0746VC0hSDHF
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod>

category:             Web, Yesod
abi:                  44008997b050d620783b3965b34faa35
exposed:              True
exposed-modules:
    Yesod Yesod.Default.Config Yesod.Default.Config2
    Yesod.Default.Handlers Yesod.Default.Main Yesod.Default.Util

import-dirs:          /usr/lib/ghc-8.10.2/site-local/yesod-1.6.1.0
library-dirs:         /usr/lib/ghc-8.10.2/site-local/yesod-1.6.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/yesod-1.6.1.0
hs-libraries:         HSyesod-1.6.1.0-DVYTfX6pgH0746VC0hSDHF
depends:
    aeson-1.5.5.1-7ZKmq9KLIncxnBfAj9HU2 base-4.14.1.0
    bytestring-0.10.10.0 conduit-1.3.4-LKkovHkWTkK2IXYqvxsWMR
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8 directory-1.3.6.0
    fast-logger-3.0.2-4brp8rjZ8ZTJd0WKKbI6MC
    file-embed-0.0.13.0-G4fwjmnadN6Cqq18FbYnBb
    monad-logger-0.3.36-7Ivl5kcncUr1znklCaMQsw
    shakespeare-2.0.25-InP8iySwSEBKoeCQgQIPBs
    streaming-commons-0.2.2.1-As0i3gD22xP4TiGwiD93Fh
    template-haskell-2.16.0.0 text-1.2.3.2 unix-2.7.2.2
    unordered-containers-0.2.13.0-HeBOjfSts31GSj9apQxnyX
    wai-3.2.2.1-BYB2v4x1FyK8eqy5kz3dj4
    wai-extra-3.1.5-8ah7ZiDfzSNDuE2iXhkFhW
    wai-logger-2.3.6-6SHz7pFnU3l1gZ4D0sNnLi
    warp-3.3.13-5YMIhxHFQMs56eMisupGvu
    yaml-0.11.5.0-ESAKkZWDHkD8oVKLu7aj5h
    yesod-core-1.6.18.8-CurW9QTzY3EBjvO5ntfMC0
    yesod-form-1.6.7-8hjiXpZ4BNG5gsaLuvdJPL
    yesod-persistent-1.6.0.5-7cO4Eb9G6m7CF6HLrs9PTu

haddock-interfaces:   /usr/share/doc/haskell-yesod/html/yesod.haddock
haddock-html:         /usr/share/doc/haskell-yesod/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

